<?php

declare(strict_types=1);

namespace Drupal\pm_app\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\notification_server\Service\NotificationServerClientInterface;
use Drupal\pm_app\Service\PmAppNotificationService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Returns responses for PM App routes.
 */
final class PmAppController extends ControllerBase {

  /**
   * Constructs a PmAppController object.
   */
  public function __construct(
    private readonly PmAppNotificationService $pmAppNotification,
    private readonly RequestStack $requestStack,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('pm_app.notification'),
      $container->get('request_stack'),
    );
  }

  /**
   * Builds the response.
   */
  public function build(): array {
    $client_id = $this->pmAppNotification->getClientId();
    $build['content'] = [
      '#type' => 'html_tag',
      '#tag' => 'div',
      '#attributes' => [
        'id' => 'root',
        'data-client-id' => $client_id,
        'data-ws-endpoint' => $this->pmAppNotification->getWebSocketEndpoint(),
      ],
      '#cache' => [
        'max-age' => 0,
      ],
      '#attached' => [
        'library' => [
          'pm_app/fem_kanban',
        ],
      ],
    ];
    return $build;
  }

}
